==> libchipcard-0.8.tar.gz: libchipcard-0.8/src/libchipcard/engine/readerservice.h <==
/***************************************************************************
 $RCSfile: readerservice.h,v $
 -------------------
 cvs         : $Id: readerservice.h,v 1.3 2003/02/17 04:17:46 aquamaniac Exp $
 begin       : Sat Jan 11 2003
 copyright   : (C) 2003 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef READERSERVICE_H
#define READERSERVICE_H


#define READERSERVICE_MSGCODE_RQ_PING 0x0000
#define READERSERVICE_MSGCODE_RQ_PING_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_PING 0x0001
#define READERSERVICE_MSGCODE_RP_PING_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_ALLOC 0x0002
#define READERSERVICE_MSGCODE_RQ_ALLOC_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_ALLOC 0x0003
#define READERSERVICE_MSGCODE_RP_ALLOC_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_RELEASE 0x0004
#define READERSERVICE_MSGCODE_RQ_RELEASE_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_RELEASE 0x0005
#define READERSERVICE_MSGCODE_RP_RELEASE_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_CONNECT 0x0006
#define READERSERVICE_MSGCODE_RQ_CONNECT_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_CONNECT 0x0007
#define READERSERVICE_MSGCODE_RP_CONNECT_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_DISCONNECT 0x0008
#define READERSERVICE_MSGCODE_RQ_DISCONNECT_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_DISCONNECT 0x0009
#define READERSERVICE_MSGCODE_RP_DISCONNECT_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_COMMAND 0x000a
#define READERSERVICE_MSGCODE_RQ_COMMAND_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_COMMAND 0x000b
#define READERSERVICE_MSGCODE_RP_COMMAND_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_FIND 0x000c
#define READERSERVICE_MSGCODE_RQ_FIND_VERSION 0x0200
#define READERSERVICE_MSGCODE_RP_FIND 0x000d
#define READERSERVICE_MSGCODE_RP_FIND_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_STATUS 0x000e
#define READERSERVICE_MSGCODE_RQ_STATUS_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_STATUS 0x000f
#define READERSERVICE_MSGCODE_RP_STATUS_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_WAIT 0x0010
#define READERSERVICE_MSGCODE_RQ_WAIT_VERSION 0x0200
#define READERSERVICE_MSGCODE_RP_WAIT 0x0011
#define READERSERVICE_MSGCODE_RP_WAIT_VERSION 0x0200

#define READERSERVICE_MSGCODE_RQ_STOPWAIT 0x0012
#define READERSERVICE_MSGCODE_RQ_STOPWAIT_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_STOPWAIT 0x0013
#define READERSERVICE_MSGCODE_RP_STOPWAIT_VERSION 0x0100


#endif

==> libchipcard-0.9.1.tar.gz: libchipcard-0.9.1/src/libchipcard/engine/readerservice.h <==
/***************************************************************************
 $RCSfile: readerservice.h,v $
 -------------------
 cvs         : $Id: readerservice.h,v 1.5 2003/04/22 22:59:23 aquamaniac Exp $
 begin       : Sat Jan 11 2003
 copyright   : (C) 2003 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef READERSERVICE_H
#define READERSERVICE_H


#define READERSERVICE_MSGCODE_RQ_PING 0x0000
#define READERSERVICE_MSGCODE_RQ_PING_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_PING 0x0001
#define READERSERVICE_MSGCODE_RP_PING_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_ALLOC 0x0002
#define READERSERVICE_MSGCODE_RQ_ALLOC_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_ALLOC 0x0003
#define READERSERVICE_MSGCODE_RP_ALLOC_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_RELEASE 0x0004
#define READERSERVICE_MSGCODE_RQ_RELEASE_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_RELEASE 0x0005
#define READERSERVICE_MSGCODE_RP_RELEASE_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_CONNECT 0x0006
#define READERSERVICE_MSGCODE_RQ_CONNECT_VERSION 0x0101
#define READERSERVICE_MSGCODE_RP_CONNECT 0x0007
#define READERSERVICE_MSGCODE_RP_CONNECT_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_DISCONNECT 0x0008
#define READERSERVICE_MSGCODE_RQ_DISCONNECT_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_DISCONNECT 0x0009
#define READERSERVICE_MSGCODE_RP_DISCONNECT_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_COMMAND 0x000a
#define READERSERVICE_MSGCODE_RQ_COMMAND_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_COMMAND 0x000b
#define READERSERVICE_MSGCODE_RP_COMMAND_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_FIND 0x000c
#define READERSERVICE_MSGCODE_RQ_FIND_VERSION 0x0200
#define READERSERVICE_MSGCODE_RP_FIND 0x000d
#define READERSERVICE_MSGCODE_RP_FIND_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_STATUS 0x000e
#define READERSERVICE_MSGCODE_RQ_STATUS_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_STATUS 0x000f
#define READERSERVICE_MSGCODE_RP_STATUS_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_WAIT 0x0010
#define READERSERVICE_MSGCODE_RQ_WAIT_VERSION 0x0201
#define READERSERVICE_MSGCODE_RP_WAIT 0x0011
#define READERSERVICE_MSGCODE_RP_WAIT_VERSION 0x0201

#define READERSERVICE_MSGCODE_RQ_STOPWAIT 0x0012
#define READERSERVICE_MSGCODE_RQ_STOPWAIT_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_STOPWAIT 0x0013
#define READERSERVICE_MSGCODE_RP_STOPWAIT_VERSION 0x0100

#define READERSERVICE_MSGCODE_RQ_STOPOPEN 0x0013
#define READERSERVICE_MSGCODE_RQ_STOPOPEN_VERSION 0x0100
#define READERSERVICE_MSGCODE_RP_STOPOPEN 0x0014
#define READERSERVICE_MSGCODE_RP_STOPOPEN_VERSION 0x0100


#endif
